/*******************************************************************************
* File Name: ALE.c  
* Version 1.70
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "ALE.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 ALE__PORT == 15 && (ALE__MASK & 0xC0))

/*******************************************************************************
* Function Name: ALE_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void ALE_Write(uint8 value) 
{
    uint8 staticBits = ALE_DR & ~ALE_MASK;
    ALE_DR = staticBits | ((value << ALE_SHIFT) & ALE_MASK);
}


/*******************************************************************************
* Function Name: ALE_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void ALE_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(ALE_0, mode);
}


/*******************************************************************************
* Function Name: ALE_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro ALE_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 ALE_Read(void) 
{
    return (ALE_PS & ALE_MASK) >> ALE_SHIFT;
}


/*******************************************************************************
* Function Name: ALE_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 ALE_ReadDataReg(void) 
{
    return (ALE_DR & ALE_MASK) >> ALE_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(ALE_INTSTAT) 

    /*******************************************************************************
    * Function Name: ALE_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 ALE_ClearInterrupt(void) 
    {
        return (ALE_INTSTAT & ALE_MASK) >> ALE_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif
/* [] END OF FILE */ 
