/*******************************************************************************
* File Name: Baud_clock_shift.h
* Version 1.60
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_CLOCK_Baud_clock_shift_H)
#define CY_CLOCK_Baud_clock_shift_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
*        Function Prototypes
***************************************/

void Baud_clock_shift_Start(void) ;
void Baud_clock_shift_Stop(void) ;

#if(!(CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3 && \
    CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_3A_ES2) && \
	!(CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC5 && \
	CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_5A_ES1))
void Baud_clock_shift_StopBlock(void) ;
#endif

void Baud_clock_shift_StandbyPower(uint8 state) ;
void Baud_clock_shift_SetDividerRegister(uint16 clkDivider, uint8 reset) ;
uint16 Baud_clock_shift_GetDividerRegister(void) ;
void Baud_clock_shift_SetModeRegister(uint8 modeBitMask) ;
void Baud_clock_shift_ClearModeRegister(uint8 modeBitMask) ;
uint8 Baud_clock_shift_GetModeRegister(void) ;
void Baud_clock_shift_SetSourceRegister(uint8 clkSource) ;
uint8 Baud_clock_shift_GetSourceRegister(void) ;
#if defined(Baud_clock_shift__CFG3)
void Baud_clock_shift_SetPhaseRegister(uint8 clkPhase) ;
uint8 Baud_clock_shift_GetPhaseRegister(void) ;
#endif

#define Baud_clock_shift_Enable()                       Baud_clock_shift_Start()
#define Baud_clock_shift_Disable()                      Baud_clock_shift_Stop()
#define Baud_clock_shift_SetDivider(clkDivider)         Baud_clock_shift_SetDividerRegister(clkDivider, 1)
#define Baud_clock_shift_SetDividerValue(clkDivider)    Baud_clock_shift_SetDividerRegister((clkDivider) - 1, 1)
#define Baud_clock_shift_SetMode(clkMode)               Baud_clock_shift_SetModeRegister(clkMode)
#define Baud_clock_shift_SetSource(clkSource)           Baud_clock_shift_SetSourceRegister(clkSource)
#if defined(Baud_clock_shift__CFG3)
#define Baud_clock_shift_SetPhase(clkPhase)             Baud_clock_shift_SetPhaseRegister(clkPhase)
#define Baud_clock_shift_SetPhaseValue(clkPhase)        Baud_clock_shift_SetPhaseRegister((clkPhase) + 1)
#endif


/***************************************
*           API Constants
***************************************/

/* Constants SetPhase(), clkPhase parameter. Only valid for PSoC 3 ES2 and earlier. See datasheet for details. */
#if CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3 && \
   (CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_3A_ES1 || \
    CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_3A_ES2)
#define CYCLK_2_5NS             0x01 /* 2.5 ns delay. */
#define CYCLK_3_5NS             0x02 /* 3.5 ns delay. */
#define CYCLK_4_5NS             0x03 /* 4.5 ns delay. */
#define CYCLK_5_5NS             0x04 /* 5.5 ns delay. */
#define CYCLK_6_5NS             0x05 /* 6.5 ns delay. */
#define CYCLK_7_5NS             0x06 /* 7.5 ns delay. */
#define CYCLK_8_5NS             0x07 /* 8.5 ns delay. */
#define CYCLK_9_5NS             0x08 /* 9.5 ns delay. */
#define CYCLK_10_5NS            0x09 /* 10.5 ns delay. */
#define CYCLK_11_5NS            0x0A /* 11.5 ns delay. */
#define CYCLK_12_5NS            0x0B /* 12.5 ns delay. */
#endif


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define Baud_clock_shift_CLKEN              (* (reg8 *) Baud_clock_shift__PM_ACT_CFG)
#define Baud_clock_shift_CLKEN_PTR          ((reg8 *) Baud_clock_shift__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define Baud_clock_shift_CLKSTBY            (* (reg8 *) Baud_clock_shift__PM_STBY_CFG)
#define Baud_clock_shift_CLKSTBY_PTR        ((reg8 *) Baud_clock_shift__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define Baud_clock_shift_DIV_LSB            (* (reg8 *) Baud_clock_shift__CFG0)
#define Baud_clock_shift_DIV_LSB_PTR        ((reg8 *) Baud_clock_shift__CFG0)
#define Baud_clock_shift_DIV_PTR            ((reg16 *) Baud_clock_shift__CFG0)

/* Clock MSB divider configuration register. */
#define Baud_clock_shift_DIV_MSB            (* (reg8 *) Baud_clock_shift__CFG1)
#define Baud_clock_shift_DIV_MSB_PTR        ((reg8 *) Baud_clock_shift__CFG1)

/* Mode and source configuration register */
#define Baud_clock_shift_MOD_SRC            (* (reg8 *) Baud_clock_shift__CFG2)
#define Baud_clock_shift_MOD_SRC_PTR        ((reg8 *) Baud_clock_shift__CFG2)

#if defined(Baud_clock_shift__CFG3)
/* Analog clock phase configuration register */
#define Baud_clock_shift_PHASE              (* (reg8 *) Baud_clock_shift__CFG3)
#define Baud_clock_shift_PHASE_PTR          ((reg8 *) Baud_clock_shift__CFG3)
#endif


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define Baud_clock_shift_CLKEN_MASK         Baud_clock_shift__PM_ACT_MSK
#define Baud_clock_shift_CLKSTBY_MASK       Baud_clock_shift__PM_STBY_MSK

/* CFG2 field masks */
#define Baud_clock_shift_SRC_SEL_MSK        Baud_clock_shift__CFG2_SRC_SEL_MASK
#define Baud_clock_shift_MODE_MASK          (~(Baud_clock_shift_SRC_SEL_MSK))

#if defined(Baud_clock_shift__CFG3)
/* CFG3 phase mask */
#define Baud_clock_shift_PHASE_MASK         Baud_clock_shift__CFG3_PHASE_DLY_MASK
#endif

#endif /* CY_CLOCK_Baud_clock_shift_H */


/* [] END OF FILE */
