/*******************************************************************************
* File Name: CyOscillator.h
* Version 1.70
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_CLOCK_CyOscillator_H)
#define CY_CLOCK_CyOscillator_H

#include <cytypes.h>
#include <cyfitter.h>

/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v1_70 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */

/***************************************
*        Function Prototypes
***************************************/

void CyOscillator_Start(void) ;
void CyOscillator_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void CyOscillator_StopBlock(void) ;
#endif

void CyOscillator_StandbyPower(uint8 state) ;
void CyOscillator_SetDividerRegister(uint16 clkDivider, uint8 reset) ;
uint16 CyOscillator_GetDividerRegister(void) ;
void CyOscillator_SetModeRegister(uint8 modeBitMask) ;
void CyOscillator_ClearModeRegister(uint8 modeBitMask) ;
uint8 CyOscillator_GetModeRegister(void) ;
void CyOscillator_SetSourceRegister(uint8 clkSource) ;
uint8 CyOscillator_GetSourceRegister(void) ;
#if defined(CyOscillator__CFG3)
void CyOscillator_SetPhaseRegister(uint8 clkPhase) ;
uint8 CyOscillator_GetPhaseRegister(void) ;
#endif

#define CyOscillator_Enable()                       CyOscillator_Start()
#define CyOscillator_Disable()                      CyOscillator_Stop()
#define CyOscillator_SetDivider(clkDivider)         CyOscillator_SetDividerRegister(clkDivider, 1)
#define CyOscillator_SetDividerValue(clkDivider)    CyOscillator_SetDividerRegister((clkDivider) - 1, 1)
#define CyOscillator_SetMode(clkMode)               CyOscillator_SetModeRegister(clkMode)
#define CyOscillator_SetSource(clkSource)           CyOscillator_SetSourceRegister(clkSource)
#if defined(CyOscillator__CFG3)
#define CyOscillator_SetPhase(clkPhase)             CyOscillator_SetPhaseRegister(clkPhase)
#define CyOscillator_SetPhaseValue(clkPhase)        CyOscillator_SetPhaseRegister((clkPhase) + 1)
#endif


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define CyOscillator_CLKEN              (* (reg8 *) CyOscillator__PM_ACT_CFG)
#define CyOscillator_CLKEN_PTR          ((reg8 *) CyOscillator__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define CyOscillator_CLKSTBY            (* (reg8 *) CyOscillator__PM_STBY_CFG)
#define CyOscillator_CLKSTBY_PTR        ((reg8 *) CyOscillator__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define CyOscillator_DIV_LSB            (* (reg8 *) CyOscillator__CFG0)
#define CyOscillator_DIV_LSB_PTR        ((reg8 *) CyOscillator__CFG0)
#define CyOscillator_DIV_PTR            ((reg16 *) CyOscillator__CFG0)

/* Clock MSB divider configuration register. */
#define CyOscillator_DIV_MSB            (* (reg8 *) CyOscillator__CFG1)
#define CyOscillator_DIV_MSB_PTR        ((reg8 *) CyOscillator__CFG1)

/* Mode and source configuration register */
#define CyOscillator_MOD_SRC            (* (reg8 *) CyOscillator__CFG2)
#define CyOscillator_MOD_SRC_PTR        ((reg8 *) CyOscillator__CFG2)

#if defined(CyOscillator__CFG3)
/* Analog clock phase configuration register */
#define CyOscillator_PHASE              (* (reg8 *) CyOscillator__CFG3)
#define CyOscillator_PHASE_PTR          ((reg8 *) CyOscillator__CFG3)
#endif


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define CyOscillator_CLKEN_MASK         CyOscillator__PM_ACT_MSK
#define CyOscillator_CLKSTBY_MASK       CyOscillator__PM_STBY_MSK

/* CFG2 field masks */
#define CyOscillator_SRC_SEL_MSK        CyOscillator__CFG2_SRC_SEL_MASK
#define CyOscillator_MODE_MASK          (~(CyOscillator_SRC_SEL_MSK))

#if defined(CyOscillator__CFG3)
/* CFG3 phase mask */
#define CyOscillator_PHASE_MASK         CyOscillator__CFG3_PHASE_DLY_MASK
#endif

#endif /* CY_CLOCK_CyOscillator_H */


/* [] END OF FILE */
