/*******************************************************************************
* File Name: P2.c  
* Version 1.70
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "P2.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 P2__PORT == 15 && (P2__MASK & 0xC0))

/*******************************************************************************
* Function Name: P2_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void P2_Write(uint8 value) 
{
    uint8 staticBits = P2_DR & ~P2_MASK;
    P2_DR = staticBits | ((value << P2_SHIFT) & P2_MASK);
}


/*******************************************************************************
* Function Name: P2_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void P2_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(P2_0, mode);
	CyPins_SetPinDriveMode(P2_1, mode);
	CyPins_SetPinDriveMode(P2_2, mode);
	CyPins_SetPinDriveMode(P2_3, mode);
	CyPins_SetPinDriveMode(P2_4, mode);
	CyPins_SetPinDriveMode(P2_5, mode);
	CyPins_SetPinDriveMode(P2_6, mode);
	CyPins_SetPinDriveMode(P2_7, mode);
}


/*******************************************************************************
* Function Name: P2_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro P2_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 P2_Read(void) 
{
    return (P2_PS & P2_MASK) >> P2_SHIFT;
}


/*******************************************************************************
* Function Name: P2_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 P2_ReadDataReg(void) 
{
    return (P2_DR & P2_MASK) >> P2_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(P2_INTSTAT) 

    /*******************************************************************************
    * Function Name: P2_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 P2_ClearInterrupt(void) 
    {
        return (P2_INTSTAT & P2_MASK) >> P2_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif
/* [] END OF FILE */ 
