/*  =============================================

	INPUTs: Xaccess_in, high, low, xtal
	OUTPUTs: ale, psen, rd, wr, ack_in 
	
	============================================= */

`include "cypress.v"

module MemIF(Xaccess_in, xtal, ale, psen, rd, wr, byte_ready, byte_ready_ex, oe, byte_in, byte_out, write_out);

	input wire [1:0] Xaccess_in;
	input wire [7:0] byte_in;
	input wire xtal;
	output reg ale, psen, rd, wr, byte_ready, byte_ready_ex, oe, write_out;
	output reg [7:0] byte_out;
	
	// Declare current state and next state variables
	reg [2:0] cs_d1, cs_d2, cs_d3, cs_p, ns;		// current clock state, next clock state
	reg [1:0] Xaccess;							// current data/program access state
	reg repeat_comm;
	
	parameter [2:0]			// states and phases of the xtal clock
		S1P1 = 3'b000,
		S1P2 = 3'b001,
		S2P1 = 3'b010,
		S2P2 = 3'b011,
		S3P1 = 3'b100,
		S3P2 = 3'b101;

	parameter [1:0]			// state: ROM read, RAM read or write
		p_fetch = 2'b00,
		d_fetch = 2'b01,
		d_write = 2'b10;
		
	parameter	
		first = 0,
		second = 1,
		third = 2;


	always @(posedge xtal)		// clock through the xtal states on each xtal period
	begin
		if (Xaccess == p_fetch)
		begin
			cs_p <= ns;
			case (cs_p)
				S1P1:
				begin
					ns <= S1P2;
					//byte_ready <= 0;
					ale <= 1;
					psen <= 1;
					write_out <= 0;
					byte_ready_ex <= 0;
				end
				S1P2:
				begin
					ns <= S2P1;
					oe <= 1;
				end
				S2P1:
				begin
					ns <= S2P2;
					ale <= 0;
				end
				S2P2:
				begin
					ns <= S3P1;
					psen <= 0;
					oe <= 0;
				end
				S3P1:
				begin
					ns <= S3P2;
				end
				S3P2:
				begin
					ns <= S1P1;
					Xaccess <= Xaccess_in;
					if (Xaccess_in != 2'b00)
					begin
						byte_ready <= 1;
						psen <= 1;
					end
					else
						byte_ready <= 0;
					byte_out <= byte_in;
					byte_ready <= 1;
					psen <= 0;
					rd <= 1;
					wr <= 1;
				end
			endcase
		end
		else if (repeat_comm == first)
		begin
			cs_d1 <= ns;				// when we decide to read or write to RAM
			case (cs_d1)
				S1P1:
				begin
					ns <= S1P2;
					ale <= 1;
					
				end
				S1P2:
				begin
					ns <= S2P1;
					oe <= 1;
				end
				S2P1:
				begin
					ns <= S2P2;
					ale <= 0;
				end
				S2P2:
				begin
					ns <= S3P1;
					
				end
				S3P1:
				begin
					ns <= S3P2;
					if (Xaccess == d_fetch)
						oe <= 0;
					else
						write_out <= 1;
				end
				S3P2:
				begin
					ns <= S1P1;
					if (Xaccess == d_write)
						wr <= 0;
					else
						rd <= 0;
					repeat_comm <= second;
				end
			endcase
		end
		else if (repeat_comm == second)
		begin
			cs_d2 <= ns;
			case(cs_d2)
				S1P1:
					ns <= S1P2;
				S1P2:
				begin
					ns <= S2P1;
					
				end
				S2P1:
					ns <= S2P2;
				S2P2:
				begin
					ns <= S3P1;
					if (Xaccess == d_fetch)
						byte_out <= byte_in;
					byte_ready_ex <= 1;
					
				end
				S3P1:
				begin
					ns <= S3P2;
					
				end
				S3P2:
				begin
					ns <= S1P1;
					//byte_ready_ex <= 0;
					if (Xaccess_in == p_fetch)
					begin
						Xaccess <= Xaccess_in;
						rd <= 1;
						wr <= 1;
						oe <= 0;
						write_out <= 0;
						repeat_comm <= first;
					end
					else
						repeat_comm <= third;
					
				end
			endcase
		end
		else
		begin
			cs_d3 <= ns;
			case(cs_d3)
				S1P1:
					ns <= S1P2;
				S1P2:
					ns <= S2P1;
				S2P1:
					ns <= S2P2;
				S2P2:
					ns <= S3P1;
				S3P1:
					ns <= S3P2;
				S3P2:
				begin
					ns <= S1P1;
					if (Xaccess_in == p_fetch)
						repeat_comm <= first;
					Xaccess <= Xaccess_in;
				end
			endcase
		end
	end
endmodule
