/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/

#include <device.h>
#include "write_read_sfr.h"
#include "sfrs.h"
#include "bit_addressable.h"
#include "comb_decomp.h"

void write_sfr_byte(uint8 add) {
	switch(add) {
		case ACC:
			InternalRAM[PSW] = (InternalRAM[PSW] & 0b11111110) | parity(InternalRAM[ACC]);	// parity bit
			break;
		case P0:
			ADD_low_Write(InternalRAM[P0]);
			break;
		case P1:
			P1_Write(InternalRAM[P1]);
			break;
		case P2:
			ADD_high_Write(InternalRAM[P2]);
			break;
		case P3:
			//P3_Write(value);
			break;
				
		/* Need a way to write to hardware registers--can we connect hardware and software registers to write automatically? */
		case TL0:
		case TL1:
		case TH0:
		case TH1:
			switch((InternalRAM[TMOD] & 0b00000011) | ((InternalRAM[TMOD] >> 2) & 0b00001100)) {
				case 1:
					Timer_0_Mode_1_WritePeriod(0x00 - comb(InternalRAM[TH0],InternalRAM[TL0]));
					break;
				case 2:
					Timer_0_Mode_2_WritePeriod(0x00 - InternalRAM[TH0]);
					break;
				case 4:
					Timer_1_Mode_1_WritePeriod(0x00 - comb(InternalRAM[TH1],InternalRAM[TL1]));
					break;
				case 12:
					Timer_1_Mode_2_WritePeriod(0x00 - InternalRAM[TH1]);
					break;
			}
			break;
		case TCON:	// if you write the whole TCON register
			Edge_Level_Write(bit_check(IT0) | (bit_check(IT1) << 1));	// edge/level select
			if (bit_check(TR0) == 0x01) {		// Timer 0 run
				switch(InternalRAM[TMOD] & 0b00000011) {
					case 1:
						Timer_0_Mode_1_Start();
						Timer_0_Mode_1_WritePeriod(0x00 - comb(InternalRAM[TH0],InternalRAM[TL0]));
						break;
					case 2:
						Timer_0_Mode_2_Start();
						Timer_0_Mode_2_WritePeriod(0x00 - InternalRAM[TH0]);
						break;
				}
			}
			if (bit_check(TR1) == 0x01) {		// Timer 1 run
				switch((InternalRAM[TMOD] >> 4) & 0b00000011) {
					case 1:
						Timer_1_Mode_1_Start();
						Timer_1_Mode_1_WritePeriod(0x00 - comb(InternalRAM[TH1],InternalRAM[TL1]));
						break;
					case 2:
						Timer_1_Mode_2_Start();
						Timer_1_Mode_2_WritePeriod(0x00 - InternalRAM[TH1]);
						break;
				}
			}
			break;
		case IE:
		case IP:
			if (bit_check(EA) == 0x00) {		// if interrupts are enabled...
				Timer0_Stop(); 	
				Timer1_Stop();
				TI_Stop();
				INT0_edge_Stop();
				INT0_level0_Stop();
				INT0_level1_Stop();
				INT1_edge_Stop();
				INT1_level0_Stop();
				INT1_level1_Stop();
			}
			if (bit_check(EX0) == 0x01) {
				switch(bit_check(IT0)) {
					case 0:
						INT0_level0_SetPriority(7*bit_check(0xB8));
						INT0_level1_SetPriority(7*bit_check(0xB8));
						INT0_level0_Start();
						INT0_level1_Start();
						break;
					case 1:
						INT0_edge_SetPriority(7*bit_check(0xB8));
						INT0_edge_Start();
						break;
				}
			}
			if (bit_check(ET0) == 0x01) {
				Timer0_SetPriority(7*bit_check(0xB9));
				Timer_0_Mode_2_Start();
				Timer0_Start();
			}
			if (bit_check(EX1) == 0x01) {
				switch(bit_check(IT1)) {
					case 0:
						INT1_level0_SetPriority(7*bit_check(0xBA));
						INT1_level1_SetPriority(7*bit_check(0xBA));
						INT1_level0_Start();
						INT1_level1_Start();
						break;
					case 1:
						
						INT1_edge_SetPriority(7*bit_check(0xBA));
						INT1_edge_Start();
						break;
				}
			}
			if (bit_check(ET1) == 0x01) {
				Timer1_SetPriority(7*bit_check(0xBB));
				Timer1_Start();
			}
			if (bit_check(ES) == 0x01) {	
				RI_SetPriority(7*bit_check(0xBC));
				TI_SetPriority(7*bit_check(0xBC));
				RI_Start();
				TI_Start();
			}
			break;
		case TMOD:
			TMOD_Write(InternalRAM[TMOD]);
			break;
		case SCON:
			if (((InternalRAM[SCON] >> 6) & 1) == 0x01) {
				UART_1_Start();
			}
			if (bit_check(REN))
				RI_Start();
			break;
		case SBUF_TX:
			UART_1_PutChar(InternalRAM[SBUF_TX]);
			bit_change(TI,0x01);
			break;
		case PWM0_FH:
		case PWM0_FL:
			PWM_0_WritePeriod(comb(InternalRAM[PWM0_FH],InternalRAM[PWM0_FL]));
			break;
		case PWM0_DH:
		case PWM0_DL:
			PWM_0_WriteCompare(comb(InternalRAM[PWM0_DH],InternalRAM[PWM0_DL]));
			break;
		case PWM0_K:
			PWM_0_WriteDeadTime(InternalRAM[PWM0_K]);
			break;
		case PH3_FH:
		case PH3_FL:
			Clock_9_SetDividerValue(comb(InternalRAM[PH3_FH],InternalRAM[PH3_FL]));
			break;
	}
}

void write_sfr_bit(uint8 add, uint8 value) {
	switch(add) {
		case Port1_0:
			switch(value) {
				case 0:
					CyPins_ClearPin(P1_0);
					break;
				default:
					CyPins_SetPin(P1_0);
					break;
			}
			break;
		case Port1_1:
			switch(value) {
				case 0:
					CyPins_ClearPin(P1_1);
					break;
				default:
					CyPins_SetPin(P1_1);
					break;
			}
			break;
		case Port1_2:
			switch(value) {
				case 0:
					CyPins_ClearPin(P1_2);
					break;
				default:
					CyPins_SetPin(P1_2);
					break;
			}
			break;
		case Port1_3:
			switch(value) {
				case 0:
					CyPins_ClearPin(P1_3);
					break;
				default:
					CyPins_SetPin(P1_3);
					break;
			}
			break;
		case Port1_4:
			switch(value) {
				case 0:
					CyPins_ClearPin(P1_4);
					break;
				default:
					CyPins_SetPin(P1_4);
					break;
			}
			break;
		case Port1_5:
			switch(value) {
				case 0:
					CyPins_ClearPin(P1_5);
					break;
				default:
					CyPins_SetPin(P1_5);
					break;
			}
			break;
		case Port1_6:
			switch(value) {
				case 0:
					CyPins_ClearPin(P1_6);
					break;
				default:
					CyPins_SetPin(P1_6);
					break;
			}
			break;
		case Port1_7:
			switch(value) {
				case 0:
					CyPins_ClearPin(P1_7);
					break;
				default:
					CyPins_SetPin(P1_7);
					break;
			}
			break;
		case TR0:
			if (bit_check(TR0) == 0x01) {		// Timer 0 run
				switch(InternalRAM[TMOD] & 0b00000011) {
					case 1:
						Timer_0_Mode_1_Start();
						Timer_0_Mode_1_WritePeriod(0x00 - comb(InternalRAM[TH0],InternalRAM[TL0]));
						break;
					case 2:
						Timer_0_Mode_2_Start();
						Timer_0_Mode_2_WritePeriod(0x00 - InternalRAM[TH0]);
						break;
				}
			}
			break;
		case TR1:
			if (bit_check(TR1) == 0x01) {		// Timer 1 run
				switch((InternalRAM[TMOD] >> 4) & 0b00000011) {
					case 1:
						Timer_1_Mode_1_Start();
						Timer_1_Mode_1_WritePeriod(0x00 - comb(InternalRAM[TH1],InternalRAM[TL1]));
						break;
					case 2:
						Timer_1_Mode_2_Start();
						Timer_1_Mode_2_WritePeriod(0x00 - InternalRAM[TH1]);
						break;
				}
			}
			break;
		case TF0:
			if (value == 0)
				Reset_Timer_Reg_0_Write(0);
			break;
		case TF1:
			if (value == 0)
				Reset_Timer_Reg_1_Write(0);
			break;
		case IT0:
		case IT1:
			Edge_Level_Write(bit_check(IT0) | (bit_check(IT1) << 1));
			break;
		case EA:		// what happens if priority is written? must be written after like period?
			if (bit_check(EA) == 0x00) {
				Timer0_Stop(); 	
				Timer1_Stop();
				TI_Stop();
				INT0_edge_Stop();
				INT0_level0_Stop();
				INT0_level1_Stop();
				INT1_edge_Stop();
				INT1_level0_Stop();
				INT1_level1_Stop();
			}
			break;
		case EX0:
			if (bit_check(EX0) == 0x01) {
				switch(bit_check(IT0)) {
					case 0:
						INT0_level0_SetPriority(7*bit_check(0xB8));
						INT0_level1_SetPriority(7*bit_check(0xB8));
						INT0_level0_Start();
						INT0_level1_Start();
						break;
					case 1:
						INT0_edge_SetPriority(7*bit_check(0xB8));
						INT0_edge_Start();
						break;
				}
			}
			break;
		case ET0:
			if (bit_check(ET0) == 0x01) {
				Timer0_SetPriority(7*bit_check(0xB9));
				Timer_0_Mode_2_Start();
				Timer0_Start();
			}
			break;
		case EX1:
			if (bit_check(EX1) == 0x01) {
				switch(bit_check(IT1)) {
					case 0:
						INT1_level0_SetPriority(7*bit_check(0xBA));
						INT1_level1_SetPriority(7*bit_check(0xBA));
						INT1_level0_Start();
						INT1_level1_Start();
						break;
					case 1:
						
						INT1_edge_SetPriority(7*bit_check(0xBA));
						INT1_edge_Start();
						break;
				}
			}
			break;
		case ET1:
			if (bit_check(ET1) == 0x01) {
				Timer1_SetPriority(7*bit_check(0xBB));
				Timer1_Start();
			}
			break;
		case ES:
			if (bit_check(ES) == 0x01) {	
				RI_SetPriority(7*bit_check(0xBC));
				TI_SetPriority(7*bit_check(0xBC));
				RI_Start();
				TI_Start();
			}
			break;
		case SM0:
		case SM1:
			if (((InternalRAM[SCON] >> 6) & 1) == 0x01) {
				UART_1_Start();
			}
			break;
		case RI:
			if (value == 0)
				RI_Enable();
			else
				RI_Disable();
			break;
		case REN:
			RI_Start();
			break;	
		case PWM0_EN:
			PWM_enable_reg_Write(bit_check(0xC0));
			PWM_0_Start();
			PWM_0_WritePeriod(comb(InternalRAM[PWM0_FH],InternalRAM[PWM0_FL]));
			PWM_0_WriteCompare(comb(InternalRAM[PWM0_DH],InternalRAM[PWM0_DL]));
			PWM_0_WriteDeadTime(InternalRAM[PWM0_K]);
			break;
		case PH3_EN:
			PWM_enable_reg_Write(bit_check(0xC1));
			Clock_9_Start();
			Clock_9_SetDividerValue(comb(InternalRAM[PH3_FH],InternalRAM[PH3_FL]));
			break;
	}
}

uint8 read_sfr(uint8 add) {
	
	switch(add) {
		case P0:
			value = P0_Read();
			break;
		case P1:
			value = P1_Read();
			break;
		case P2:
			value = P2_Read();
			break;
		case P3:
			//value = P3_Read();
			break;	
		default:
			value = InternalRAM[add];
			break;
	}
	return value;
}



/* [] END OF FILE */
